#!/bin/sh 

if [ ! -f gs3-setup.sh ]; then
    echo "You must run this script from within the Greenstone 3 home directory"
    exit 1
fi

#check that GSDL3HOME is set
if test -z "$GSDL3HOME" ; then
  source gs3-setup.sh
fi

if test -z "$CVSROOT" ; then
  echo "You need to set the environment variable CVSROOT before running"
  echo "this script. Please use the same path that you used to check out"
  echo "the Greentone repository. If you are not using anonymous cvs, you"
  echo "also need to set the variable CVS_RSH to ssh."
  exit;
fi
 
# firstly, remove unwanted directories
cvs update -dRP

# now check out extra bits
cd packages
cvs co mgpp
cd $GSDL3HOME

# unpack tomcat and rename directory
cd comms/jakarta/
tar xzf tomcat-4.1.24.tar.gz 
mv jakarta-tomcat-4.1.24 tomcat
cd $GSDL3HOME

# unpack the soap stuff
cd comms/soap
tar xzf soap-bin-2.2.tar.gz
mv soap-2_2 soap
cd $GSDL3HOME

#setup sample collections
cd web/sites/localsite/collect

for f in */index; do
  cd $f
  if test -f indexfiles.tgz; then
    tar xzf indexfiles.tgz
  fi
  cd ../../
done

cd $GSDL3HOME


#edit the tomcat setclasspath script to add our classpath
cat comms/jakarta/tomcat/bin/setclasspath.sh | sed 's,CLASSPATH=,CLASSPATH=\"$CLASSPATH\":,' > setclasspath.sh
mv comms/jakarta/tomcat/bin/setclasspath.sh comms/jakarta/tomcat/bin/setclasspath.bak.sh
mv setclasspath.sh comms/jakarta/tomcat/bin/setclasspath.sh

#edit the server config file
mv comms/jakarta/tomcat/conf/server.xml comms/jakarta/tomcat/conf/server.xml.orig
cat comms/jakarta/tomcat/conf/server.xml.orig | sed "s,<\!-- Tomcat Root Context -->,<\!-- GSDL3 Service --><Context path=\"/gsdl3\" docBase=\"@gsdl3home@/web\" debug=\"1\" reloadable=\"true\"><Resources allowLinking='true'/></Context><\!-- Tomcat Root Context -->," > comms/jakarta/tomcat/conf/server.xml.in

#make everyone happy by giving the right permissions to the shell scripts
chmod a+x comms/jakarta/tomcat/bin/*.sh

